ParseError

Struct ParseError 

pub struct ParseError<E> {
    pub kind: ParseErrorKind<E>,
}
Extensible parse errors that can be encountered by client parsing implementations.

Fields

kind: ParseErrorKind<E>

Details of this error

Implementations

Source

impl<T> ParseError<T>

pub fn from_basic_kind(kind: BasicParseErrorKind) -> Self

Create a new ParseError from a basic error kind.

pub fn unexpected_token() -> Self

Create a new ParseError for an unexpected token.

pub fn custom<E: Into<T>>(error: E) -> Self

Create a new ParseError from a consumer-defined error.

pub fn basic(self) -> BasicParseError

Extract the fundamental parse error from an extensible error.

pub fn into<U>(self) -> ParseError<U>
where T: Into<U>,

Like std::convert::Into::into