pub struct SourceLocation {
pub line: u32,
pub column: u32,
}Expand description
The line and column number for a given position within the input.
Fields
line: u32The line number, starting at 0 for the first line.
column: u32The column number within a line, starting at 1 for first the character of the line. Column numbers are counted in UTF-16 code units.