[−][src]Enum cssparser::Token
One of the pieces the CSS input is broken into.
Some components use Cow in order to borrow from the original input string
and avoid allocating/copying when possible.
Variants
Ident(CowRcStr<'a>)AtKeyword(CowRcStr<'a>)The value does not include the @ marker.
Hash(CowRcStr<'a>)A <hash-token> with the type flag set to "unrestricted"
The value does not include the # marker.
IDHash(CowRcStr<'a>)A <hash-token> with the type flag set to "id"
The value does not include the # marker.
QuotedString(CowRcStr<'a>)The value does not include the quotes.
UnquotedUrl(CowRcStr<'a>)The value does not include the url( ) markers. Note that url( <string-token> ) is represented by a
Function token.
Delim(char)A <delim-token>
NumberFields of Number
PercentageFields of Percentage
DimensionFields of Dimension
has_sign: boolWhether the number had a + or - sign.
This is used is some cases like the <An+B> micro syntax. (See the parse_nth function.)
value: f32The value as a float
int_value: Option<i32>If the origin source did not include a fractional part, the value as an integer.
unit: CowRcStr<'a>The unit, e.g. "px" in 12px
WhiteSpace(&'a str)Comment(&'a str)A comment.
The CSS Syntax spec does not generate tokens for comments, But we do, because we can (borrowed &str makes it cheap).
The value does not include the /* */ markers.
ColonA : <colon-token>
SemicolonA ; <semicolon-token>
CommaA , <comma-token>
IncludeMatchDashMatchA |= <dash-match-token>
PrefixMatchA ^= <prefix-match-token>
SuffixMatchA $= <suffix-match-token>
SubstringMatchCDOA <!-- <CDO-token>
CDCA --> <CDC-token>
Function(CowRcStr<'a>)The value (name) does not include the ( marker.
ParenthesisBlockA <(-token>
SquareBracketBlockA <[-token>
CurlyBracketBlockA <{-token>
BadUrl(CowRcStr<'a>)A <bad-url-token>
This token always indicates a parse error.
BadString(CowRcStr<'a>)A <bad-string-token>
This token always indicates a parse error.
CloseParenthesisA <)-token>
When obtained from one of the Parser::next* methods,
this token is always unmatched and indicates a parse error.
CloseSquareBracketA <]-token>
When obtained from one of the Parser::next* methods,
this token is always unmatched and indicates a parse error.
CloseCurlyBracketA <}-token>
When obtained from one of the Parser::next* methods,
this token is always unmatched and indicates a parse error.
Methods
impl<'a> Token<'a>[src]
pub fn is_parse_error(&self) -> bool[src]
Return whether this token represents a parse error.
BadUrl and BadString are tokenizer-level parse errors.
CloseParenthesis, CloseSquareBracket, and CloseCurlyBracket are unmatched
and therefore parse errors when returned by one of the Parser::next* methods.
impl<'a> Token<'a>[src]
pub fn serialization_type(&self) -> TokenSerializationType[src]
Categorize a token into a type that determines when /**/ needs to be inserted
between two tokens when serialized next to each other without whitespace in between.
See the TokenSerializationType::needs_separator_when_before method.