pub struct ParseError<E> {
pub kind: ParseErrorKind<E>,
}Expand description
Extensible parse errors that can be encountered by client parsing implementations.
Fields
kind: ParseErrorKind<E>Details of this error
Implementations
Sourceimpl<T> ParseError<T>
impl<T> ParseError<T>
Sourcepub fn from_basic_kind(kind: BasicParseErrorKind) -> Self
pub fn from_basic_kind(kind: BasicParseErrorKind) -> Self
Create a new ParseError from a basic error kind.
Sourcepub fn unexpected_token() -> Self
pub fn unexpected_token() -> Self
Create a new ParseError for an unexpected token.
Sourcepub fn custom<E: Into<T>>(error: E) -> Self
pub fn custom<E: Into<T>>(error: E) -> Self
Create a new ParseError from a consumer-defined error.
Sourcepub fn basic(self) -> BasicParseError
pub fn basic(self) -> BasicParseError
Extract the fundamental parse error from an extensible error.
Sourcepub fn into<U>(self) -> ParseError<U>where
T: Into<U>,
pub fn into<U>(self) -> ParseError<U>where
T: Into<U>,
Like std::convert::Into::into